@@ -197,7 +197,7 @@ impl<T: Pep508Url + Display> Display for Requirement<T> {
 }
 
 /// <https://github.com/serde-rs/serde/issues/908#issuecomment-298027413>
-impl<'de, T: Pep508Url + Deserialize<'de>> Deserialize<'de> for Requirement<T> {
+impl<'de, T: Pep508Url> Deserialize<'de> for Requirement<T> {
     fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
     where
         D: Deserializer<'de>,
@@ -551,11 +551,6 @@ impl Extras {
     pub fn parse<T: Pep508Url>(input: &str) -> Result<Self, Pep508Error<T>> {
         Ok(Self(parse_extras_cursor(&mut Cursor::new(input))?))
     }
-
-    /// Convert the [`Extras`] into a [`Vec`] of [`ExtraName`].
-    pub fn into_vec(self) -> Vec<ExtraName> {
-        self.0
-    }
 }
 
 /// The actual version specifier or URL to install.
