@@ -1,7 +1,7 @@
 use uv_cache::Refresh;
 use uv_configuration::ConfigSettings;
 use uv_resolver::PreReleaseMode;
-use uv_settings::{InstallerOptions, PipOptions, ResolverInstallerOptions, ResolverOptions};
+use uv_settings::{PipOptions, ResolverInstallerOptions, ResolverOptions};
 
 use crate::{
     BuildArgs, IndexArgs, InstallerArgs, Maybe, RefreshArgs, ResolverArgs, ResolverInstallerArgs,
@@ -76,6 +76,7 @@ impl From<InstallerArgs> for PipOptions {
             index_strategy,
             keyring_provider,
             config_setting,
+            exclude_newer,
             link_mode,
             compile_bytecode,
             no_compile_bytecode,
@@ -88,6 +89,7 @@ impl From<InstallerArgs> for PipOptions {
             keyring_provider,
             config_settings: config_setting
                 .map(|config_settings| config_settings.into_iter().collect::<ConfigSettings>()),
+            exclude_newer,
             link_mode,
             compile_bytecode: flag(compile_bytecode, no_compile_bytecode),
             ..PipOptions::from(index_args)
@@ -164,59 +166,6 @@ impl From<IndexArgs> for PipOptions {
     }
 }
 
-/// Construct the [`InstallerOptions`] from the [`InstallerArgs`] and [`BuildArgs`].
-pub fn installer_options(installer_args: InstallerArgs, build_args: BuildArgs) -> InstallerOptions {
-    let InstallerArgs {
-        index_args,
-        reinstall,
-        no_reinstall,
-        reinstall_package,
-        index_strategy,
-        keyring_provider,
-        config_setting,
-        link_mode,
-        compile_bytecode,
-        no_compile_bytecode,
-    } = installer_args;
-
-    let BuildArgs {
-        no_build,
-        build,
-        no_build_package,
-        no_binary,
-        binary,
-        no_binary_package,
-    } = build_args;
-
-    InstallerOptions {
-        index_url: index_args.index_url.and_then(Maybe::into_option),
-        extra_index_url: index_args.extra_index_url.map(|extra_index_urls| {
-            extra_index_urls
-                .into_iter()
-                .filter_map(Maybe::into_option)
-                .collect()
-        }),
-        no_index: if index_args.no_index {
-            Some(true)
-        } else {
-            None
-        },
-        find_links: index_args.find_links,
-        reinstall: flag(reinstall, no_reinstall),
-        reinstall_package: Some(reinstall_package),
-        index_strategy,
-        keyring_provider,
-        config_settings: config_setting
-            .map(|config_settings| config_settings.into_iter().collect::<ConfigSettings>()),
-        link_mode,
-        compile_bytecode: flag(compile_bytecode, no_compile_bytecode),
-        no_build: flag(no_build, build),
-        no_build_package: Some(no_build_package),
-        no_binary: flag(no_binary, binary),
-        no_binary_package: Some(no_binary_package),
-    }
-}
-
 /// Construct the [`ResolverOptions`] from the [`ResolverArgs`] and [`BuildArgs`].
 pub fn resolver_options(resolver_args: ResolverArgs, build_args: BuildArgs) -> ResolverOptions {
     let ResolverArgs {
